@@ -7,7 +7,7 @@ import (
 	"path/filepath"
 
 	"github.com/beringresearch/macpine/host"
-	qemu "github.com/beringresearch/macpine/qemu"
+	"github.com/beringresearch/macpine/qemu"
 	"github.com/beringresearch/macpine/utils"
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v3"
@@ -15,8 +15,8 @@ import (
 
 // shellCmd starts an Alpine instance
 var shellCmd = &cobra.Command{
-	Use:   "ssh NAME",
-	Short: "Attach an interactive shell to an instance.",
+	Use:   "ssh <instance>",
+	Short: "Attach an interactive shell to an instance via ssh.",
 	Run:   shell,
 
 	ValidArgsFunction:     host.AutoCompleteVMNames,
@@ -31,13 +31,13 @@ func shell(cmd *cobra.Command, args []string) {
 	}
 
 	if len(args) == 0 {
-		log.Fatal("missing VM name")
+		log.Fatal("missing instance name")
 	}
 
 	vmList := host.ListVMNames()
 	exists := utils.StringSliceContains(vmList, args[0])
 	if !exists {
-		log.Fatal("unknown machine " + args[0])
+		log.Fatal("unknown instance " + args[0])
 	}
 
 	machineConfig := qemu.MachineConfig{}
@@ -52,6 +52,9 @@ func shell(cmd *cobra.Command, args []string) {
 		log.Fatal(err)
 	}
 
+	if status, _ := machineConfig.Status(); status != "Running" {
+		log.Fatalf("%s is not running", machineConfig.Alias)
+	}
 	err = host.Exec(machineConfig, "bash")
 	if err != nil {
 		log.Fatal(err)
